#[non_exhaustive]pub struct Lifetime(pub u32);Expand description
constraint lifetime
These values represent different lifetime semantics. They are passed as arguments to the factory requests to specify how the constraint lifetimes should be managed.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations
Sourceimpl Lifetime
impl Lifetime
Sourcepub const Oneshot: Self
pub const Oneshot: Self
the pointer constraint is defunct once deactivated
A oneshot pointer constraint will never reactivate once it has been deactivated. See the corresponding deactivation event (wp_locked_pointer.unlocked and wp_confined_pointer.unconfined) for details.
Sourcepub const Persistent: Self
pub const Persistent: Self
the pointer constraint may reactivate
A persistent pointer constraint may again reactivate once it has been deactivated. See the corresponding deactivation event (wp_locked_pointer.unlocked and wp_confined_pointer.unconfined) for details.